Adsorption sites
================

.. automodule:: acat.adsorption_sites
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: get_labels, new_site, get_two_vectors, is_eq, get_angle, make_fullCNA, get_site_dict, set_first_neighbor_distance_from_rdf, get_surface_designation, make_neighbor_list

Adsorbate coverage
==================

.. automodule:: acat.adsorbate_coverage
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: identify_adsorbates, make_ads_neighbor_list  







